pub struct SharedPgTransaction<'conn> { /* private fields */ }Trait Implementations
Sourcefn query(
&self,
cx: &Cx,
sql: &str,
params: &[Value],
) -> impl Future<Output = Outcome<Vec<Row>, Error>> + Send
fn query( &self, cx: &Cx, sql: &str, params: &[Value], ) -> impl Future<Output = Outcome<Vec<Row>, Error>> + Send
Execute a query within this transaction.
Sourcefn query_one(
&self,
cx: &Cx,
sql: &str,
params: &[Value],
) -> impl Future<Output = Outcome<Option<Row>, Error>> + Send
fn query_one( &self, cx: &Cx, sql: &str, params: &[Value], ) -> impl Future<Output = Outcome<Option<Row>, Error>> + Send
Execute a query and return the first row, if any.
Sourcefn execute(
&self,
cx: &Cx,
sql: &str,
params: &[Value],
) -> impl Future<Output = Outcome<u64, Error>> + Send
fn execute( &self, cx: &Cx, sql: &str, params: &[Value], ) -> impl Future<Output = Outcome<u64, Error>> + Send
Execute a statement within this transaction.
Sourcefn savepoint(
&self,
cx: &Cx,
name: &str,
) -> impl Future<Output = Outcome<(), Error>> + Send
fn savepoint( &self, cx: &Cx, name: &str, ) -> impl Future<Output = Outcome<(), Error>> + Send
Create a savepoint within this transaction. Read more
Sourcefn rollback_to(
&self,
cx: &Cx,
name: &str,
) -> impl Future<Output = Outcome<(), Error>> + Send
fn rollback_to( &self, cx: &Cx, name: &str, ) -> impl Future<Output = Outcome<(), Error>> + Send
Rollback to a previously created savepoint. Read more
Sourcefn release(
&self,
cx: &Cx,
name: &str,
) -> impl Future<Output = Outcome<(), Error>> + Send
fn release( &self, cx: &Cx, name: &str, ) -> impl Future<Output = Outcome<(), Error>> + Send
Release a savepoint, making the changes permanent within the transaction. Read more